.. _get_started:

Get started
===========

:program:`calorine` can be readily installed from PyPI as described in the :ref:`installation section <installation>`.
The tutorials below illustrate various functionalities and workflows enabled by :program:`calorine`.

.. toctree::
   :hidden:

   installation

.. toctree::
   :caption: NEP calculators
   :maxdepth: 2

   calculators

.. _model_training_tutorial:

.. toctree::
   :caption: Training NEP models
   :maxdepth: 2

   generate_training_structures_and_training

.. _phonons_tutorial:
.. _free_energy_tutorial:

.. toctree::
   :caption: Working with NEP models
   :maxdepth: 2

   structure_relaxation
   phonons
   elastic_stiffness_tensor
   free_energy_tutorial
   thermal_conductivity_from_bte
   simulating_ins

.. _nep_analysis_tutorial:

.. toctree::
   :caption: Analyzing NEP models
   :maxdepth: 2

   nep_descriptors
   nep_model_inspection
   visualize_descriptor_space_with_pca

.. _misc:

.. toctree::
   :caption: Miscellaneous
   :maxdepth: 2

   faq
